@@ -1,13 +1,18 @@
-class AccessError(Exception):
+class GeocodioError(Exception):
+    """General but unknown error from Geocodio"""
+    pass
+
+
+class GeocodioAuthError(GeocodioError):
     """HTTP 403 Access Forbidden, likely due to bad API key"""
     pass
 
 
-class UnprocessableError(Exception):
+class GeocodioDataError(GeocodioError):
     """HTTP 422 Unprocessable Entity, likely poorly formed address"""
     pass
 
 
-class ServerError(Exception):
+class GeocodioServerError(GeocodioError):
     """HTTP 500 Server Error, remote server failure"""
     pass
